==> formio__semantic-1.2.3.jar: META-INF/resources/webjars/formio__semantic/1.2.3/lib/index.d.ts <==
declare const _default: {
    framework: string;
    templates: {
        semantic: {
            table: {
                form: string;
            };
            webform: {
                form: string;
                builder: string;
            };
            well: {
                form: string;
            };
            wizard: {
                form: string;
                builder: string;
            };
            treeView: {
                form: string;
            };
            treeEdit: {
                form: string;
            };
            transform(type: any, text: any): any;
            defaultIconset: string;
            iconClass: (iconset: any, name: any, spinning: any) => string;
            cssClasses: {
                'has-error': string;
                'is-invalid': string;
                'formio-tab-panel-active': string;
                'formio-tab-link-active': string;
                'formio-tab-link-container-active': string;
            };
            builder: {
                form: string;
            };
            builderComponent: {
                form: string;
            };
            builderComponents: {
                form: string;
            };
            builderEditForm: {
                form: string;
            };
            builderPlaceholder: {
                form: string;
            };
            builderSidebar: {
                form: string;
            };
            builderSidebarGroup: {
                form: string;
            };
            builderWizard: {
                form: string;
            };
            button: {
                form: string;
                html: string;
            };
            checkbox: {
                form: string;
                html: string;
            };
            columns: {
                form: string;
            };
            component: {
                form: string;
            };
            datagrid: {
                form: string;
                html: string;
            };
            day: {
                form: string;
            };
            editgrid: {
                form: string;
                html: string;
            };
            field: {
                form: string;
            };
            fieldset: {
                form: string;
            };
            file: {
                form: string;
            };
            icon: {
                form: string;
            };
            input: {
                form: string;
                html: string;
            };
            label: {
                form: string;
            };
            loader: {
                form: string;
            };
            loading: {
                form: string;
            };
            message: {
                form: string;
            };
            multiValueRow: {
                form: string;
            };
            multiValueTable: {
                form: string;
            };
            panel: {
                form: string;
            };
            radio: {
                form: string;
                html: string;
            };
            resourceAdd: {
                form: string;
            };
            select: {
                form: string;
                html: string;
            };
            selectOption: {
                form: string;
                html: string;
            };
            signature: {
                form: string;
                html: string;
            };
            survey: {
                form: string;
                html: string;
            };
            tab: {
                flat: string;
                form: string;
            };
            tree: {
                form: string;
            };
        };
    };
};
export default _default;

==> formio__semantic-2.6.0.jar: META-INF/resources/webjars/formio__semantic/2.6.0/lib/index.d.ts <==
declare const _default: {
    framework: string;
    templates: {
        semantic: {
            table: {
                form: string;
            };
            webform: {
                form: string;
                builder: string;
            };
            well: {
                form: string;
            };
            wizard: {
                form: string;
                builder: string;
            };
            wizardHeader: {
                form: string;
            };
            wizardHeaderClassic: {
                form: string;
            };
            wizardHeaderVertical: {
                form: string;
            };
            wizardNav: {
                form: string;
            };
            alert: {
                form: string;
            };
            errorsList: {
                form: string;
            };
            treeView: {
                form: string;
            };
            treeEdit: {
                form: string;
            };
            transform(type: any, text: any): any;
            defaultIconset: string;
            iconClass: (iconset: any, name: any, spinning: any) => string;
            cssClasses: {
                'has-error': string;
                'is-invalid': string;
                'formio-tab-panel-active': string;
                'formio-tab-link-active': string;
                'formio-tab-link-container-active': string;
            };
            builder: {
                form: string;
            };
            builderComponent: {
                form: string;
            };
            builderComponents: {
                form: string;
            };
            builderEditForm: {
                form: string;
            };
            builderPlaceholder: {
                form: string;
            };
            builderSidebar: {
                form: string;
            };
            builderSidebarGroup: {
                form: string;
            };
            builderWizard: {
                form: string;
            };
            button: {
                form: string;
                html: string;
            };
            checkbox: {
                form: string;
                html: string;
            };
            columns: {
                form: string;
            };
            component: {
                form: string;
            };
            datagrid: {
                form: string;
                html: string;
            };
            day: {
                form: string;
            };
            editgrid: {
                form: string;
                html: string;
            };
            field: {
                form: string;
                align: string;
            };
            fieldset: {
                form: string;
            };
            file: {
                form: string;
            };
            icon: {
                form: string;
            };
            input: {
                form: string;
                html: string;
            };
            label: {
                form: string;
            };
            loader: {
                form: string;
            };
            loading: {
                form: string;
            };
            message: {
                form: string;
            };
            multiValueRow: {
                form: string;
            };
            multiValueTable: {
                form: string;
            };
            panel: {
                form: string;
            };
            radio: {
                form: string;
                html: string;
            };
            resourceAdd: {
                form: string;
            };
            select: {
                form: string;
                html: string;
            };
            selectOption: {
                form: string;
                html: string;
            };
            signature: {
                form: string;
                html: string;
            };
            survey: {
                form: string;
                html: string;
            };
            tab: {
                flat: string;
                form: string;
            };
            tree: {
                form: string;
            };
        };
    };
};
export default _default;
